;********************************************************************************************
;* Title:  DEMO.ASM                        (c) MOTOROLA Inc. 2003 All rights reserved.
;********************************************************************************************
;* Author: Bill Lucas - Motorola TSPG
;*
;* Description: 9S08GB60 demo program parser.
;*
;* This program decides which of the three demo programs will run if the
;* monitor does not take control at reset/power-up.
;
;* There are three demo programs:
;* 1) A low power demo that will use the real time interrupt to wake
;*    the CPU from stop3 mode. It is the default program
;
;* 2) A program that increases or decreases the duty cycle of TPM1, channel 2
;*    which drives an integrator to create a D/A output. The D/A output is
;*    connected to channel 1 of the analog to digital converter. The converted
;*    input to the A/D is passed to timer 1, channel 0 which changes duty cycle
;*    to an LED, thus varing the brightness of the A/D in proportion to the D/A
;*    output. It is activated by pressing SW3 at power-up.
;
;* 3. A paced loop that runs every 100 ms. Within the pased loop, a 0 to 60
;*    second counter is maintained. Two leds are blinked, based off of the
;*    0 to 60 second timer. One LED blinks at a 1 second rate. The second LED
;*    blinks at a 2 second rate. It is activated by pressing SW2 at power-up.
;*
;* Documentation: 9S08GB60 family Data Sheet and HCS08 Family Reference Manual (HCS08RM1/D)
;*
;* Include Files: 9S08GB60_v1.EQU, RTI_DEMO.ASM, PWM_ATD.ASM, PACED_LOOP.ASM, VECTORS.H
;*
;* Assembler:  Metrowerks Code Warrior 3.0 (pre-release)
;*             or P&E Microcomputer Systems - CASMS08 (beta v4.02)
;*
;* Revision History: 
;* Rev #     Date       Who        Comments
;* -----  -----------  ------     --------------------------------------------
;*  1.3    07-May-03   J.Suchyta   ABSENTRY for debugger; new equate file
;*  1.2    25-Apr-03   B.Lucas     Correct minor typos in comments
;*  1.1    21-Apr-03   B.Lucas     Comments and modify for CW 3.0 project
;*  1.0    02-Apr-03   B.Lucas     Initial code release
;********************************************************************************************

             ABSENTRY Demo_start

             nolist
             include "9S08GB60v1r3.inc"
             list
;
             include "DEMO.H"
             org    Rom1Start

Demo_start   equ    *
             ldx    #initSOPT
             stx    SOPT          ;turn off COP and enable STOP
	
;* Set-up ICG to clock the bus at 18.874 MHz
             mov    #initICGC2,ICGC2 ;sets MFD divider
             mov    #initICGC1,ICGC1 ;32.768 kHz -> 18.874 MHz bus rate
             brclr  LOCK,ICGS1,*  ;loop until FLL locks


             jsr    clear_cnt     ;initialize rti demo counters
             mov    #mLED,PTFD    ;outputs specific to this demo, LED's off
             mov    #mLED,PTFDD   ;all LED bits = output
	
             bsr    set_IO        ;initialize unused I/O
	
             cli
	
;* Set-up ICG to clock the bus at 18.874 MHz
             mov    #initICGC2,ICGC2 ;sets MFD divider
             mov    #initICGC1,ICGC1 ;32.768 kHz -> 18.874 MHz bus rate
             brclr  LOCK,ICGS1,*  ;loop until FLL locks	
	
             lda    PTAD	;read the switches
             and    #(mSW2|mSW3)  ;isolate SW2 and SW3
             cmp    #(mSW2|mSW3)  ;is either push button depressed?
             beq    xRTI_DEMO     ;no..run program 1
             brclr  SW3,SWITCH_PORT,xPWM_ATD ;run program 2
             jmp    PACED_LOOP    ;else run program 3
;
xRTI_DEMO    lda    #(mRTIE|mRTIS2|mRTIS1)
             sta    SRTISC        ;1/2 sec and RTI int enabled
             jmp    RTI_DEMO      ;extend the branch past 8 bits
xPWM_ATD     jmp    PWM_ATD       ;extend the branch past 8 bits

set_IO       mov    #pull_pat,PTAPE ;pull-up port A
             mov    #pull_pat,PTBPE ;pull-up port B
             mov    #pull_pat,PTCPE ;pull-up port C
             mov    #pull_pat,PTDPE ;pull-up port D
             mov    #pull_pat,PTEPE ;pull-up port E
             mov    #pull_pat,PTFPE ;pull-up port F
             mov    #mIRQPE,IRQSC ;pull-up and enable IRQ
             bset   IRQACK,IRQSC
             rts

             include "RTI_DEMO.ASM"
             include "PWM_ATD.ASM"
             include "PACED_LOOP.ASM"
             include "VECTORS.H"

