;********************************************************************************************
;* Title:  DEMO.H                        (c) MOTOROLA Inc. 2003 All rights reserved.
;********************************************************************************************
;* Author: Bill Lucas - Motorola TSPG
;*
;* Description: Demo header file
;*
;* This file contains RAM variables and constants used by the three demo programs.
;*
;* Documentation: 9S08GB60 family Data Sheet and HCS08 Family Reference Manual (HCS08RM1/D)
;*
;* Include Files: none
;*
;* Assembler:  Metrowerks Code Warrior 3.0 (pre-release)
;*             or P&E Microcomputer Systems - CASMS08 (beta v4.02)
;*
;* Revision History:  not yet released
;* Rev #     Date       Who     Comments
;* -----  -----------  ------  --------------------------------------------
;*  1.2    25-Apr-03   B.Lucas  Correct minor typos in comments
;*  1.1    18-Apr-03   B.Lucas  Comments and modify for CW 3.0 project
;*  1.0    02-Apr-03   B.Lucas  Initial code release
;********************************************************************************************

             org    RamStart

;* Variables and constants for DEMO.ASM follow:

pull_pat     equ    $ff	;pull-up pattern for I/O ports

mSW1         equ    %00010000     ;mask for port A bit 4
mSW2         equ    %00100000     ;mask for port A bit 5
mSW3         equ    %01000000     ;mask for port A bit 6
mSW4         equ    %10000000     ;mask for port A bit 7

mALL_SW      equ    %11110000     ;mask for all switches

SW1          equ    4             ;SW1 connected to Port A, bit 4
SW2          equ    5             ;SW2 connected to Port A, bit 5
SW3          equ    6             ;SW3 connected to Port A, bit 6
SW4          equ    7             ;SW4 connected to Port A, bit 7

SWITCH_PORT  equ    PTAD          ;switches connected to Port A

;* Variables and constants for RTI_DEMO.ASM follow:

initSOPT:    equ    %01110011     ;COP and STOP enable controls
;                    |||   ||
;                    |||   |+-RSTPE --- Reset pin enabled
;                    |||   +--BKGDPE -- BKGD pin enabled
;                    ||+------STOPE --- STOP allowed
;                    |+-------COPT ---- long timeout 2^18
;                    +--------COPE ---- COP off

initICGC2:   equ    %01110000     ;Clock Generator Control 2
;                    ||||||||       should write MFDx before ICGC1
;                    |||||||+-RFD0 \
;                    ||||||+--RFD1  --- post-PLL divider (div by 1)
;                    |||||+---RFD2 /
;                    ||||+----LOCRE --- loss of clock doesn't reset
;                    |||+-----MFD0 \
;                    ||+------MFD1  --- FLL loop multiplier N = 18x
;                    |+-------MFD2 /
;                    +--------LOLRE --- loss of lock doesn't reset
; after FLL init, LOCRE will be set to force reset on clock loss

initICGC1:   equ    %00111000     ;Clock Generator Control 1
;                    0|||||xx       this setting for 32.768KHz
;                     ||||+---OSCSTEN - don't keep osc on in stop mode
;                     |||+----CLKS0 \ - select FLL engaged external
;                     ||+-----CLKS1 /    (FEE) mode
;                     |+------REFS ---- enable oscillator amplifier
;                     +-------RANGE --- 32.768KHz crystal

LED          equ    0		;LED1 is connected to Port F, bit 0

;*****************************************************************

;* Variables and constants for PWM_ATD.ASM follow:


pwm_initSOPT: equ   %01110011     ;COP and STOP enable controls
;                    |||   ||
;                    |||   |+-RSTPE --- Reset pin enabled
;                    |||   +--BKGDPE -- BKGD pin enabled
;                    ||+------STOPE --- STOP allowed
;                    |+-------COPT ---- long timeout 2^18
;                    +--------COPE ---- COP off
;
;
;* Initialize the ATD for contenious 8-bit conversion, on channel 1

delay_cntr   ds     1             ;delay to count TPU overflows


;*****************************************************************

;* Variables and constants for PACED_LOOP.ASM follow:

;
MAIN_flag    equ    7             ;bit 7
FLAG_mask    equ    $f            ;isolate bottom 4 bits
ONE_SECOND   equ    10t           ;1 second = 10 overflow interrupts
TPM_COUNT    equ    14745t
LED1         equ    0             ;LED1 is connected to Port F, bit 0
LED2         equ    1             ;LED2 is connected to Port F, bit 1
LED3         equ    2             ;LED3 is connected to Port F, bit 2
LED4         equ    3             ;LED4 is connected to Port F, bit 3
mLED         equ    %00001111     ;mask for all LED's

Tick_100ms   ds     1             ;100 millisecond counter, bits 0:3 
;		and use bit 7 as a flag to main to trigger user code
Tock_1sec    ds     1             ;1 second counter

;*****************************************************************

;* Variables and constants for RTI_DEMO.ASM follow:
timer_led    equ    5             ; 5 counts * 0.512 sce
;                                 = ~2.5 seconds LED on time
rti_cnt1     ds     1             ;on timer for LED1
rti_cnt2     ds     1             ;on timer for LED2
rti_cnt3     ds     1             ;on timer for LED3
rti_cnt4     ds     1             ;on timer for LED4

